@@ -62,7 +62,6 @@ use G::Seq::Tandem;
 use G::Seq::Util;
 use G::Seq::Markov;
 use G::Seq::Align;
-use G::Seq::Usage;
 use G::Seq::COMGA;
 use G::Seq::GenomeMap;
 use G::Seq::ImaGene;
@@ -100,7 +99,7 @@ use G::System::CHI;
 use G::System::ReL8;
 use G::System::FuncD;
 
-our @EXPORT = qw(load);
+our @EXPORT = qw(load opt_list);
 
 # export odyssay functions
 push(@EXPORT, @G::Seq::AminoAcid::EXPORT);
@@ -116,7 +115,6 @@ push(@EXPORT, @G::Seq::Tandem::EXPORT);
 push(@EXPORT, @G::Seq::Util::EXPORT);
 push(@EXPORT, @G::Seq::Markov::EXPORT);
 push(@EXPORT, @G::Seq::Align::EXPORT);
-push(@EXPORT, @G::Seq::Usage::EXPORT);
 push(@EXPORT, @G::Seq::COMGA::EXPORT);
 push(@EXPORT, @G::Seq::ImaGene::EXPORT);
 push(@EXPORT, @G::Seq::GenomeMap::EXPORT);
@@ -169,6 +167,16 @@ sub load{
     return new G(@_);
 }
 
+sub opt_list{
+    my $sub = shift;
+
+    set_opt_list(1);
+    eval("&{$sub}");
+    set_opt_list(0);
+
+    return opt_val();
+}
+
 #::::::::::::::::::::::::::::::
 #          Perldoc
 #::::::::::::::::::::::::::::::
@@ -853,6 +861,49 @@ G - G-language Genome Analysis Environment core interface module
 
 =cut
 
+=head2 $gb->reverse_strand()
+
+   Name: $gb->reverse_strand()   -   create a G instance on complementary DNA strand
+
+   Description:
+         Returns a G instance for the complementary DNA strand. 
+         All information, including the sequence and feature annotations
+         is switched to reflect that of the complementary DNA strand. 
+         In other words, gene order, direction of genes (either direct or 
+         complement), and positions are reversed. 
+
+   Usage: 
+      $new = $gb->reverse_strand();
+
+=cut
+
+=head2 $gb->relocate_origin()
+
+   Name: $gb->relocate_origin()   -   create a G instance starting at given position
+
+   Description:
+         Returns a G instance starting at given position, assuming circular
+         chromosome. All information, including the sequence and feature 
+         annotations are moved. 
+
+   Usage:
+      $new = $gb->relocate_origin($position);
+
+      This method would probably be most useful in conjunction with
+      find_ori_ter(), to create a G instance starting from the 
+      origin of replication, as follows:
+
+        ($ori, $ter) = find_ori_ter($gb);
+        $new = $gb->relocate_origin($ori);
+
+      Several of related methods can be concatenated. For example, 
+      to create a GenBank file of complementary DNA strand starting
+      from the origin of replication, do the following:
+
+        $gb->reverse_strand()->relocate_origin($ori)->output("out.gbk");
+
+=cut
+
 
 =head1 AUTHOR
 
