@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GenBankO.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -34,12 +32,6 @@ package G::IO::GenBankO;
 use strict;
 use G::Messenger;
 
-use vars qw($VERSION @ISA @INC $AUTOLOAD);
-
-@ISA = qw();
-
-$VERSION = '1.0';
-
 #::::::::::::::::::::::::::::::
 #     Let the code begin...
 #::::::::::::::::::::::::::::::
@@ -198,39 +190,5 @@ sub make_gb {
 }
 
 
-#::::::::::::::::::::::::::::::
-#          Perldoc
-#::::::::::::::::::::::::::::::
 
 1;
-
-__END__
-
-=head1 NAME
-
-G::IO::GenBankO
-
-=head1 SYNOPSIS
-
- use G::IO::GenBankO;
- @ISA = (G::IO::GenBankO);
-   
-=head1 DESCRIPTION
-
- GenBank output.
- Intended for internal use only.
-
-=back
-
-=head1 AUTHOR
-
-Kazuharu Arakawa, gaou@sfc.keio.ac.jp
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
