@@ -112,7 +112,7 @@ sub find {
 	foreach my $key (keys %keyhash){
 	    my $val = $keyhash{$key};
 
-	    unless($this->{$feat}->{$key} =~ /$val/){
+	    unless($this->{$feat}->{$key} =~ /$val/i){
 		$flag = 1;
 		last;
 	    }
@@ -121,7 +121,7 @@ sub find {
 	next if ($flag);
 
 	foreach my $key (@keywords){
-	    unless(join('%%%___%%%', values(%{$this->{$feat}})) =~ /$key/){
+	    unless(join('%%%___%%%', values(%{$this->{$feat}})) =~ /$key/i){
 		$flag = 1;
 		last;
 	    }
@@ -665,6 +665,157 @@ sub seq{
 }
 
 
+
+sub relocate_origin{
+    require G::IO;
+    my $this = new G::IO("blessed");
+    my $tmp = shift;
+    my $gb = $tmp->clone();
+    my $pos = shift;
+    die("New start position \(in Perl coordinate\) must be given.\n") unless($pos =~ /\d/);
+
+    $this->{LOCUS} = $gb->{LOCUS};
+    $this->{HEADER} = $gb->{HEADER};
+    $this->{COMMENT} = $gb->{COMMENT};
+    $this->{SEQ} = substr($gb->{SEQ}, $pos) . substr($gb->{SEQ}, 0, $pos);
+    $this->{FEATURE0} = $gb->{FEATURE0};
+
+    my (@before, @after);
+    my @features = $gb->feature();
+    shift @features;
+    foreach my $feature (@features){
+	if($gb->{$feature}->{start} >= $pos + 1){
+	    push(@after, $feature);
+	}else{
+	    push(@before, $feature);
+	}
+    }
+
+    my $f = 0;
+    my $c = 0;
+    foreach my $feature (@after, @before){
+	$f ++;
+	$this->{"FEATURE$f"} = $gb->{$feature};
+	$this->{"FEATURE$f"}->{feature} = $f;
+	if($gb->{$feature}->{type} eq 'CDS'){
+	    $c ++;
+	    $this->{"FEATURE$f"}->{cds} = $c;
+	}
+
+	if($gb->{$feature}->{end} >= $pos + 1 && $gb->{$feature}->{start} < $pos + 1){
+	    $this->{"FEATURE$f"}->{start} += length($gb->{SEQ}) - $pos;
+	    $this->{"FEATURE$f"}->{end} -= $pos;
+
+	    if(length $this->{"FEATURE$f"}->{join}){
+		msg_error("Warning: overriding join definition for FEATURE$f.\n");
+		msg_error("  this is likely to destroy positional features of this gene entry.\n");
+	    }
+
+	    $this->{"FEATURE$f"}->{join} = sprintf("%d\.\.%d,%d\.\.%d", $this->{"FEATURE$f"}->{start},
+						   length($gb->{SEQ}), 1, $this->{"FEATURE$f"}->{end});
+	    next;
+	}
+
+	my $lng = length($gb->{SEQ}) - $pos;
+	if($gb->{$feature}->{start} >= $pos + 1){
+	    $lng = -$pos;
+	}
+
+	$this->{"FEATURE$f"}->{start} += $lng;
+	$this->{"FEATURE$f"}->{end} += $lng;
+
+	if(defined $this->{"FEATURE$f"}->{"join"}){
+	    my @join = split(/\,/,$this->{"FEATURE$f"}->{"join"});
+	    my @num = ();
+	    my @new_join = ();
+
+	    foreach(@join){
+		if(tr/c/c/){
+		    @num = split(/\.\./,$_);
+		    push (@new_join, sprintf ("c%d\.\.%d", $num[0] + $lng, $num[1] + $lng));
+		} else {
+		    @num = split(/\.\./,$_);
+		    push (@new_join, sprintf ("%d\.\.%d",  $num[0] + $lng, $num[1] + $lng));
+		}
+	    }
+	    $this->{"FEATURE$f"}->{join} = join(',', @new_join);
+	}
+    }
+    
+    $this->set_gene_aliases();
+
+    return $this;
+}
+
+
+sub reverse_strand{
+    require G::IO;
+    my $this = new G::IO("blessed");
+    my $tmpG = shift;
+    my $gb = $tmpG->clone();
+
+    $this->{LOCUS} = $gb->{LOCUS};
+    $this->{HEADER} = $gb->{HEADER};
+    $this->{COMMENT} = $gb->{COMMENT};
+    $this->{SEQ} = complement($gb->{SEQ});
+    $this->{FEATURE0} = $gb->{FEATURE0};
+
+    my @feat = $gb->feature();
+    shift @feat;
+    my (@features, @tmp);
+    foreach my $feature (@feat){
+	if($gb->{$feature}->{type} eq 'gene'){
+	    unshift(@features, @tmp);
+	    @tmp = ($feature);
+	}else{
+	    push(@tmp, $feature);
+	}
+    }
+    unshift(@features, @tmp);
+
+    my $f = 0;
+    my $c = 0;
+    my $lng = length($gb->{SEQ}) + 1;
+    foreach my $feature (@features){
+	$f ++;
+	$this->{"FEATURE$f"} = $gb->{$feature};
+	$this->{"FEATURE$f"}->{feature} = $f;
+
+	if($gb->{$feature}->{type} eq 'CDS'){
+	    $c ++;
+	    $this->{"FEATURE$f"}->{cds} = $c;
+	}
+
+	my ($start, $end) = ($lng - $gb->{$feature}->{end}, $lng - $gb->{$feature}->{start});
+	$this->{"FEATURE$f"}->{start} = $start;
+	$this->{"FEATURE$f"}->{end}   = $end;
+	$this->{"FEATURE$f"}->{direction} = $gb->{$feature}->{direction} eq 'direct' ? 'complement' : 'direct';
+
+	if(defined $this->{"FEATURE$f"}->{"join"}){
+	    my @join = split(/\,/,$this->{"FEATURE$f"}->{"join"});
+	    my @num = ();
+	    my @new_join = ();
+
+	    foreach(@join){
+		if(tr/c/c/){
+		    @num = split(/\.\./,$_);
+		    push (@new_join, sprintf ("c%d\.\.%d", $lng - $num[1], $lng - $num[0]));
+		} else {
+		    @num = split(/\.\./,$_);
+		    push (@new_join, sprintf ("%d\.\.%d",  $lng - $num[1], $lng - $num[0]));
+		}
+	    }
+	    $this->{"FEATURE$f"}->{join} = join(',', reverse(@new_join));
+	}
+    }
+    $this->set_gene_aliases();
+
+    return $this;
+}
+
+
+
+
 sub hairpin_cut {
     my $nuc = shift;
     my $val = "\n==============\n!!!Afro Man!!!===============\n\n";
