@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Inspire.pm,v 1.2 2002/05/27 03:32:43 gaou Exp $
@@ -32,21 +30,18 @@
 package G::Inspire;
 
 use strict;
-use Cwd;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-use G::Messenger;
-
+use base qw(Exporter);
+use autouse 'Cwd'=>qw(getcwd);
 use SelfLoader;
 
-require Exporter;
+use G::Messenger;
 
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
-	     SetScript
-	     OnSave
-	     OnExecute
-	     OnGenerate
-);
+our @EXPORT = qw(
+		 SetScript
+		 OnSave
+		 OnExecute
+		 OnGenerate
+		 );
 
 
 
@@ -150,31 +145,5 @@ sub OnGenerate {
 
 
 1;
-__END__
-
-
-=head1 NAME
-
-G::Inspire.pm G-language Inspire Core API
-
-=head1 SYNOPSIS
-
-  use G::Inspire;
-
-
-=head1 DESCRIPTION
-
-  blah blah blah
-
-=head1 AUTHOR
-
-  Kazuharu Arakawa, gaou@sfc.keio.ac.jp
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
 
 
