@@ -393,6 +393,9 @@ sub leading_strand {
 
   Options:
    -window      number of windows. must be a power of 2. (default: 4096)
+   -purine      use purine skew for calculation (default: 0)
+   -keto        use keto skew for calculation (default: 0)
+   -at          use AT skew for calculation (default: 0)
 
   References:
     1. Arakawa K, Tomita M (2007) "The GC skew index: a measure of genomic compositional 
@@ -402,6 +405,8 @@ sub leading_strand {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+   20080421-01 added -at, -purine and -keto options
+   20070313-01 added error message for when genome size is too small
    20070707-01 initial posting
 
 =cut
@@ -411,15 +416,22 @@ sub gcsi{
     require Statistics::Descriptive;
     require Math::FFT;
 
-    opt_default(window=>4096);
+    opt_default(window=>4096, purine=>0, keto=>0, at=>0);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $power = opt_val("window");
+    my $purine = opt_val("purine");
+    my $keto = opt_val("keto");
+    my $at = opt_val("at");
+    my $lowpass = opt_val("filter");
 
     my $window = int(length($gb->{SEQ}) / $power);
-
+    if($window < 10){
+	die("Error in gcsi: number of windows is too large, or the genome is too small.\n" . 
+	    "GCSI would not be accurate for genomes smaller than 100,000 bp\n");
+    }
     my @gcskew = gcskew($gb, -output=>"/dev/null", -window=>$window);
-    my @cumgcskew = gcskew($gb, -output=>"/dev/null", -window=>$window, -cumulative=>1);
+    my @cumgcskew = gcskew($gb, -output=>"/dev/null", -window=>$window, -cumulative=>1, -purine=>$purine, -keto=>$keto, -at=>$at);
 
     while(scalar @gcskew > $power){
         pop @gcskew;
@@ -506,7 +518,7 @@ sub gcsi{
 
 sub gcskew {
     &opt_default(window=>10000, at=>0, purine=>0, keto=>0, output=>"show", 
-		 filename=>"gcskew.png", -cumulative=>0);
+		 filename=>"gcskew.png", cumulative=>0);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $ref = \$gb->{SEQ};
@@ -622,7 +634,7 @@ sub cum_gcskew {
    intergenic regions, and the third codon.
 
  Usage: 
-    1 = genomicskew($genome);
+   (\@gcskew, \@geneskew, \@betskew, \@thirdskew) = genomicskew($genome);
 
  Options:
    -divide      window number to divide into (default: 250)
@@ -638,6 +650,7 @@ sub cum_gcskew {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
+   20080421-01 now returns references of result arrays
    20040610-01 updated to handle introns and exons
    20040601-01 bug fix for output=>"f" option
    20010905-01 updated options
@@ -775,7 +788,7 @@ sub genomicskew {
 	close(OUT);
     }
     
-    return 1;
+    return (\@gcskew, \@geneskew, \@betskew, \@thirdskew);
 }
 
 
