@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Primitive.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -31,15 +29,11 @@ package G::Seq::ImaGene;
 use SubOpt;
 use G::Messenger;
 use G::Tools::Graph;
-use Statistics::Descriptive;
 
 use strict;
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
 	     ma_normalize
 	     ma_filter
@@ -234,6 +228,8 @@ sub ma_filter{
 
 
 sub ma_rfilter{
+    require Statistics::Descriptive;
+
     my ($tmp1, $tmp2) = _read_master();
     my %ma2ec = %$tmp1;
     my %ma2jw = %$tmp2;
