@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: PatSearch.pm,v 1.3 2002/07/30 17:40:56 gaou Exp $
@@ -32,18 +32,19 @@ use G::Tools::Graph;
 use G::Seq::Primitive;
 
 use strict;
+use base qw(Exporter);
 use SelfLoader;
-require Exporter;
-
-our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
 	     palindrome
+	     signature
 	     oligomer_search
 	     oligomer_counter
-	     find_ter
+	     find_pattern
 	     find_dnaAbox
 	     find_dif
+	     find_ter
+	     find_iteron
 	     baseParingTest
 	     nucleotide_periodicity
 );
@@ -66,12 +67,128 @@ our @EXPORT = qw(
 
 =cut
 
-#__DATA__
+__DATA__
 
 #::::::::::::::::::::::::::::::
 #        Methods Start
 #::::::::::::::::::::::::::::::
 
+
+
+=head2 signature
+
+  Name: signature   -   calculate oligonucleotide usage (genomic signature)
+
+  Description:
+   This program calculates short oligonucleotide usage (genomic signature),
+   defined as the ratio of observed (O) to expected (E) oligonucleotide frequencies.
+   O/E value of dinucleotide CG at position 1..500 will be accessible at 
+   $gb->{1..500}->{signature}->{'cg'}.
+    
+  Usage: 
+   NULL = &signature(G instance);
+
+  Options:
+   -output      output option (default: 'stdout')
+                'stdout' for standard output,
+                'f' for file output in directory "data"
+   -filename    output filename (default: 'signature.csv')
+   -wordlength  word length (default: 2)
+   -start       start position (default: 1)
+   -end         end position (default: 0)
+                0 for using whole genome sequence; i.e. -end=>length($gb->{SEQ});
+
+  Author: 
+   Haruo Suzuki (haruo@g-language.org)
+
+  History:
+   20071107 initial posting
+
+  Informations stored in the G instance:
+    $gb->{"header_signature"}
+
+  References:
+   Campbell A et al. (1999) Proc Natl Acad Sci U S A. 96(16):9184-9.
+   Karlin S. (2001) Trends Microbiol. 9(7):335-43.
+
+  Requirements: none.
+
+=cut
+
+sub signature {
+    &opt_default(output=>'stdout',filename=>'signature.csv',wordlength=>2,start=>1,end=>0);
+    my @args = opt_get(@_);
+    my $gb = opt_as_gb(shift @args);
+    my $output = opt_val("output");
+    my $filename = opt_val("filename");
+    my $wordlength = opt_val("wordlength");
+    my $start = opt_val("start");
+    my $end = opt_val("end");
+    my %mono;
+    my %obs;
+    my %exp;
+    my %oe;
+
+    $end = length($gb->{SEQ}) unless($end);
+    my $seq = $gb->getseq($start, $end);
+    my $seq2 = reverse($seq);    
+    $seq2 =~ tr
+	[acgturymkdhbvwsn]
+	[tgcaayrkmhdvbwsn];
+
+    for(my $i; $i < length($seq) - $wordlength; $i ++){
+	$mono{substr($seq, $i, 1)} ++;
+	$mono{substr($seq2, $i, 1)} ++;
+	$obs{substr($seq, $i, $wordlength)} ++;
+	$obs{substr($seq2, $i, $wordlength)} ++;
+    }
+
+    my $total; 
+    foreach (keys %mono){ $total += $mono{$_}; }
+    foreach (keys %mono){ $mono{$_} =  $mono{$_} / $total; }
+    $total = 0;
+    foreach (keys %obs){ $total += $obs{$_}; }
+    foreach (keys %obs){ $obs{$_} =  $obs{$_} / $total; }
+    foreach (keys %obs){ delete $obs{$_} if($_ =~ /[^acgt]/); }
+    foreach (keys %obs){
+	$exp{$_} = 1;
+	for(my $i = 0; $i < $wordlength; $i ++){ $exp{$_} *= $mono{substr($_,$i,1)}; }
+    }
+    foreach (keys %obs){ $oe{$_} = sprintf("%.3f", $obs{$_} / $exp{$_}); }
+
+    $gb->{"$start..$end"}->{signature} = \%oe; # input in the G instance
+
+    my @allkey = qw(a c g t);
+    for(1..($wordlength-1)){
+	my @tmp = ();
+	for my $base (qw(a c g t)){
+	    foreach my $key (@allkey){ push(@tmp, $key.$base); }
+	}
+	@allkey = @tmp;
+    }
+    @allkey = sort @allkey;
+		     
+    if($output =~ /stdout/){
+	msg_send("\n\nstart\tend\t"); foreach(@allkey){ msg_send("$_\t"); }
+	msg_send("\n$start\t$end\t"); foreach(@allkey){ msg_send("$oe{$_}\t"); }
+    }
+    if($output eq 'f'){
+	mkdir ("data", 0777);
+	open(FILE,">>data/$filename");
+	#open(FILE,">>$filename");
+	unless($gb->{"header_signature"}){
+	    print FILE "start,end,";
+	    foreach(@allkey){ print FILE "$_,"; }
+	    $gb->{"header_signature"} = 1;
+        }
+	print FILE "\n$start,$end,";
+	foreach(@allkey){ print FILE (exists $oe{$_}) ? "$oe{$_}," : "0,"; }
+	close(FILE);
+    }
+}
+
+
+
 =head2 palindrome
 
  Name: palindrome   -   searches palindrome sequences
@@ -194,42 +311,40 @@ sub palindrome {
     -type    ecoli for E.coli dif (default)
              proteobacteria, bsub, firmicute, actinobacteria, for corresponding dif sequences.
     
+  References:
+    1. Hendrickson H, Lawrence JG (2007) "Mutational bias suggests that replication 
+       termination occurs near the dif site, not at Ter sites",  Mol Microbiol. 64(1):42-56.
+    2. Blakely G, Sherratt D (1994) "Determinants of selectivity in Xer site-specific 
+       recombination" Genes Dev. 10:762-773.
+    3. Sciochetti SA, Piggot PJ, Blakely GW (2001) "Identification and characterization 
+       of the dif site from Bacillus subtilis." J Bacteriol. 183:1058-1068.
+  
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
     
   History:
+    20071028-01 fixed a bug that did not properly search the complement 
+    20071023-01 updated to include dif consensus of other organisms
     20060711-01 initial posting
 
 =cut
 
 
-
-sub find_dif{
-    opt_default('output'=>'stdout', -type=>'ecoli');
+sub find_dif {
+    opt_default(-type=>'ecoli');
     my @argv = opt_get(@_);
-    my $gb = opt_as_gb(shift @argv);
-    my $output = opt_val("output");
     my $type = lc opt_val('ecoli');
     my $dif = 'ggtgcgcataatgtatattatgttaaat';
-    $dif = 'rntkcgcataatgtatattatgttaaat' if ($type eq 'proteobacteria');
-    $dif = 'acttcctagaatatatattatgtaaact' if ($type eq 'bsub');
-    $dif = 'actkystakaatrtatattatgtwaact' if ($type eq 'firmicute');
-    $dif = 'ttsrccgataatvnacattatgtccagt' if ($type eq 'actinobacteria');
+    $dif    = 'rntkcgcataatgtatattatgttaaat' if ($type eq 'proteobacteria');
+    $dif    = 'acttcctagaatatatattatgtaaact' if ($type eq 'bsub');
+    $dif    = 'actkystakaatrtatattatgtwaact' if ($type eq 'firmicute');
+    $dif    = 'ttsrccgataatvnacattatgtccagt' if ($type eq 'actinobacteria');
 
-    my %data = oligomer_search($gb, $dif, -return=>"both"), oligomer_search($gb, complement($dif), -return=>"both");
-
-    if($output eq 'stdout'){
-	foreach my $pos (sort keys %data){
-	    msg_send(sprintf "%d %s\n", $pos, $data{$pos});
-	}
-    }
-
-    return sort keys %data;
+    return find_pattern(@_, $dif);
 }
 
 
 
-
 =head2 find_ter
 
  Name: find_ter   -   finds ter sequence (replication termination site)
@@ -240,46 +355,47 @@ sub find_dif{
     For E. coli,              5'-AGNATGTTGTAAYKAA-3',              (Coskun-Ari and Hill, 1997)
     for B. subtilis,          5'-KMACTAANWNNWCTATGTACYAAATNTTC-3', (Wake, 1997)
     
+    Note that E.coli Ter consensus allows substitutions at bases 1, 4, and 16, 
+    that are NOT considered in this method. 
+
   Usage: 
     @position = find_ter($sequence)
     
   Options:
     -type    ecoli for E.coli ter (default)
              bsub, for corresponding ter sequence.
-    
+
+  References:
+    1. Hendrickson H, Lawrence JG (2007) "Mutational bias suggests that replication 
+       termination occurs near the dif site, not at Ter sites",  Mol Microbiol. 64(1):42-56
+    2. Coskun-Ari, FF, Hill TM (1997) "Sequence-specific interactions in the Tus-Ter 
+       complex and the effect of base pair substitutions on arrest of DNA replication 
+       in Escherichia coli", J Biol Chem. 272:26448-26456.
+    3. Wake RG (1997) "Replication fork arrest and termination of chromosome replication 
+       in Bacillus subtilis", FEMS Microbiol Lett. 153:24-56.
+   
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
     
   History:
+    20071028-01 fixed a bug that did not properly search the complement 
     20071022-01 initial posting
 
 =cut
 
 
 
-sub find_ter{
-    opt_default('output'=>'stdout', -type=>'ecoli');
+sub find_ter {
+    opt_default(-type=>'ecoli');
     my @argv = opt_get(@_);
-    my $gb = opt_as_gb(shift @argv);
-    my $output = opt_val("output");
     my $type = lc opt_val('ecoli');
     my $ter = 'agnatgttgtaaykaa';
     $ter = 'kmactaanwnnwctatgtacyaaatnttc' if ($type eq 'bsub');
 
-    my %data = oligomer_search($gb, $ter, -return=>"both"), oligomer_search($gb, complement($ter), -return=>"both");
-
-    if($output eq 'stdout'){
-	foreach my $pos (sort keys %data){
-	    msg_send(sprintf "%d %s\n", $pos, $data{$pos});
-	}
-    }
-
-    return sort keys %data;
+    return find_pattern(@_, $ter);
 }
 
 
-
-
 =head2 find_dnaAbox
 
  Name: find_dnaAbox   -   finds dnaA box in both strands
@@ -293,33 +409,98 @@ sub find_ter{
   Options:
     -output    stdout to print data (default: stdout)
     
+  References:
+    1. Schaper S, Messer W (1995) "Interaction of the initiator protein DnaA of 
+       Escherichia coli with its DNA target", J Biol Chem, 270(29):17622-17626
+
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
     
   History:
+    20071028-01 fixed a bug that did not properly search the complement 
     20071022-01 updated the code to use oligomer_search()
     20021125-01 initial posting
 
 =cut
 
-
-
 sub find_dnaAbox {
+    return find_pattern(@_, "ttwtncaca");
+}
+
+
+
+
+=head2 find_iteron
+
+ Name: find_iteron   -   finds iteron in both strands
+
+  Description:
+    Finds iteron (TGAGGG G/A C/T) in both strands.
+    
+  Usage: 
+    @positions = find_iteron($genome)
+    
+  Options:
+    -output    stdout to print data (default: stdout)
+    
+  References:
+    1. Haines AS, Akhtar P, Stephens ER, Jones K, Thomas CM, Perkins CD, Williams JR, 
+       Day MJ, Fry JC (2006) "Plasmids from freshwater environments capable of IncQ 
+       retrotransfer are diverse and include pQKH54, a new IncP-1 subgroup archetype.",
+       Microbiology, 152(Pt 9):2689-2701
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+    
+  History:
+    20071107-01 initial posting
+
+=cut
+
+
+sub find_iteron {
+    return find_pattern(@_, "tgaggry");
+}
+
+=head2 find_pattern
+
+ Name: find_pattern   -   finds oligomer pattern in both strands
+
+  Description:
+    Finds given oligomer pattern specified in degenerate nucleotide code in both strands.
+    This method serves as the basic function for other find_* methods.
+
+  Usage: 
+    @positions = find_patter($genome, "pattern")
+    
+  Options:
+    -output    stdout to print data (default: stdout)
+    
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+    
+  History:
+    20071107-01 initial posting
+=cut
+
+
+
+sub find_pattern {
     opt_default('output'=>'stdout');
     my @argv = opt_get(@_);
     my $gb = opt_as_gb(shift @argv);
+    my $pattern = shift @argv;
     my $output = opt_val("output");
-    my $dnaAbox = "ttwtncaca";
-    my %data = oligomer_search($gb, $dnaAbox, -return=>"both"), oligomer_search($gb, complement($dnaAbox), -return=>"both");
+    my %data = (oligomer_search($gb, $pattern, -return=>"both"), oligomer_search($gb, complement($pattern), -return=>"both"));
 
     if($output eq 'stdout'){
-	foreach my $pos (sort keys %data){
+	foreach my $pos (sort  {$a<=>$b}keys %data){
 	    msg_send(sprintf "%d %s\n", $pos, $data{$pos});
 	}
     }
 
     return sort keys %data;
-}
+}    
 
 
 
@@ -333,7 +514,9 @@ sub find_dnaAbox {
     regular expressions.
 
   Usage: 
-    $count = oligomer_counter($genome);
+    $count = oligomer_counter($genome, $oligomer);
+      or
+    %octamers = oligomer_counter($genome, -length=>8);
 
  Options:
     -window      int window size.
@@ -341,14 +524,18 @@ sub find_dnaAbox {
                  Method returns an array of numbers at each windows
                  If not specified, seeks oligomer in the genome
                  Method returns the number of oligomers
-    -output      "f" for file output, "g" for graph output
+    -output      "f" for file output, "g" for graph output, "show"
+                 to display the graph.
                  Only available when -window option is specified
+    -length      If specified, returns a hash containing number counts
+                 for all n-mers.
 
   Author: 
-    Kazuharu Arakawa
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
     -based on atg7.wind + gcwind [rsaito]
 
   History:
+    20071107-01 added -length option
     20071022-01 oligomer can be now degenerate nucleotide code or regular expressions
     20010829-01 initial posting
 
@@ -364,17 +551,18 @@ sub oligomer_counter {
     my $seq = shift @args;
     my $window = opt_val("window");
     my $output = opt_val("output");
+    my $length = opt_val("length");
+
     $window = length($gb->{SEQ}) if($window <= 0);
 
     if (opt_val("window")){
+	die("Error in oligomer_counter: oligomer not specified.") unless(length($seq));
 	open(OUT, '>oligo_count.csv') || &msg_error($!) if ($output eq "f");
 
-	my $i = 0;
-	my @wincount = ();
-	my @winnum = ();
-	for ($i = 0; $i <= int(length($gb->{SEQ}) / $window); $i ++){
-	    my $partial = substr($gb->{SEQ}, $i * $window, $window);
-	    last if (length($partial) < $window);
+	my (@wincount, @winnum);
+	for (my $i = 0; $i <= length($gb->{SEQ}) - $window; $i += $window){
+	    my $partial = substr($gb->{SEQ}, $i, $window);
+
 	    my $count = 0;
 	    if (length($seq) == 1 && $seq =~ /[atgc]/){
 		$count = $partial =~ tr/a/a/ if ($seq eq 'a');
@@ -385,19 +573,26 @@ sub oligomer_counter {
 		$count = scalar oligomer_search($partial, $seq);
 	    }
 	    push (@wincount, $count);
-	    push (@winnum, $i * $window);
-	    print OUT "%d,%d\n", $i*$window, $count if ($output eq "f");
+	    push (@winnum, $i);
+	    printf OUT "%d,%d\n", $i, $count if ($output eq "f");
 	}
-	close(OUT) if ($output eq "f");
-	if ($output eq "g"){
-	    _UniMultiGrapher(\@winnum, \@wincount, -x=>'window(bp)', 
-			  -y=>'number of oligomer', 
-			  -title=>'oligomer by window',
-			  -outfile=>'oligo_count.png'
-			  );
+	close(OUT) if ($output eq 'f');
+	if ($output eq 'g' || $output eq 'show'){
+	    grapher(\@winnum, \@wincount, -x=>'window(bp)', 
+		    -y=>'number of oligomer', 
+		    -title=>'oligomer by window',
+		    -outfile=>'oligo_count.png', -output=>$output
+		    );
 	}
 	return (@wincount);
+    }elsif($length){
+	my %oligo;
+	for(my $i = 0; $i <= length($gb->{SEQ}) - $length; $i ++){
+	    $oligo{substr($gb->{SEQ}, $i, $length)} ++;
+	}
+	return %oligo;
     }else{
+	die("Error in oligomer_counter: oligomer not specified.") unless(length($seq));
 	return scalar oligomer_search($gb, $seq);
     }
 }
