@@ -34,6 +34,7 @@ use File::Find;
 use G::DB::SDB;
 use G::Messenger;
 
+
 our @EXPORT = qw(
 		 help
 		 buildHelpDB
@@ -127,17 +128,20 @@ sub buildHelpDB{
    -s         search through documentation with keyword
    -g         same as above, but only for G-language GAE manual
    -bp        same as above, but only for BioPerl manual
+   -w         search through BioMOBY web services
+              when the <keyword> is the name of available service,
+              description of the web service is provided.
 
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+   20080227-01 added -w option
    20080214-01 replaced print with msg_send, and also returns the string
    20070531-01 initial posting
 
 =cut
 
-
 sub help{
     buildHelpDB() unless(scalar %pdoc);
 
@@ -145,47 +149,99 @@ sub help{
 
     if ($key =~ /^\-(\S+)/){
 	my $option = $1;
+	
 	$key = join(' ', @_);
-
+	my $lckey = lc($key);
 	my $ans = "     Keyword \"$key\" was not found in the documentations.\n";
 
-	my $lckey = lc($key);
-	my @tmp;;
-	    
-	foreach my $keyword (sort keys %pdoc){
-	    if ($keyword =~ /Bio/){
-		next if ($option =~ 'g');
+	if($option eq 'w'){
+	    require MOBY::Client::Central;
+	    my $m = MOBY::Client::Central->new();
+
+	    my ($sv, undef) = $m->findService(serviceName=>$key);
+	    if(scalar(@$sv) == 1){
+		$ans = "\n";
+		$ans .= '    ' . 'Name: ' . $$sv[0]->{name}. "\n\n";
+		$ans .= '    ' . "Description:\n" 
+		    . '      ' . $$sv[0]->{description} .  "\n\n\n";
+		
+		$ans .= '    ' . "Input:\n";
+		foreach my $in ( @{$$sv[0]->{input}}){ 
+		    $ans .= sprintf("      %-20s\n\t\t   Object:   %-30s\n\t\tNamespace:   %-30s\n", $in->articleName, $in->objectType, join(' ', @{$in->namespaces}));
+		}
+		$ans .= "\n\n\n";
+		
+		$ans .= '    ' . "Output:\n";
+		foreach my $in ( @{$$sv[0]->{output}}){ 
+		    $ans .= sprintf("      %-20s\n\t\t   Object:   %-30s\n\t\tNamespace:   %-30s\n", $in->articleName, $in->objectType, join(' ', @{$in->namespaces}));
+		}
+		$ans .= "\n\n\n";
+		
+		$ans .= '      ' . 'Authority : ' . $$sv[0]->{authority}. "\n";
+		$ans .= '      ' . 'Contact   : ' . $$sv[0]->{contactEmail}. "\n";
+		$ans .= '      ' . 'Type      : ' . $$sv[0]->{type}. "\n";
+		$ans .= '      ' . 'Category  : ' . $$sv[0]->{category}. "\n";
+		$ans .= '      ' . 'URL       : ' . $$sv[0]->{URL}. "\n";
+		$ans .= '      ' . 'LSID      : ' . $$sv[0]->{LSID}. "\n";
 	    }else{
-		next if ($option =~ 'b');
-	    }
+		my @tmpsv = @$sv;
+		
+		($sv, undef) = $m->findService(keywords=>[split(/\s+/, $lckey)]);
 
-	    if(lc($pdoc{$keyword}) =~ /$lckey/){
-		push(@tmp, $keyword);
-	    }elsif(length($lckey) < 1){
-		push(@tmp, $keyword);
-	    }
-	}
-	    
-	if(scalar(@tmp)){
-	    $ans = sprintf("     Found keyword \"%s\" in the following manual pages \(%s hits\).\n\n", $key, scalar(@tmp));
-	    
-	    foreach my $entry (@tmp){
-		my $tmp = $pdoc{$entry};
+		push(@tmpsv, @$sv);
 
-		my $abstract;
-		if($tmp =~ /Name:\s*(.*)(   -   .*?)\_\_\%\%\%\%\%\_\_/){
-		    $abstract = $2;
+		if(scalar(@tmpsv)){
+		    $ans = sprintf("     Found keyword \"%s\" in the following web services \(%s hits\).\n\n", $key, scalar(@tmpsv));
+
+		    my %tmp;
+		    foreach my $in (@$sv){
+			$in->{description} =~ s/\n/   /g;
+			$in->{description} =~ s/^\s+//g;
+			$tmp{$in->{name}} = ':   ' . substr($in->{description}, 0, 50) . '...';
+		    }
+		    foreach my $key (sort keys %tmp){
+			$ans .= sprintf("       %-40s%s\n", $key, $tmp{$key});
+		    }
 		}
+	    }    
+	    
+	}else{
+	    my @tmp;
 
-		if($entry =~ /Bio::/){
-		    $ans .= sprintf("              %s\n",$entry);
-		}elsif($entry){
-		    $ans .= sprintf("       %-30s%s\n",$entry, $abstract);
+	    foreach my $keyword (sort keys %pdoc){
+		if ($keyword =~ /Bio/){
+		    next if ($option =~ 'g');
+		}else{
+		    next if ($option =~ 'b');
+		}
+		
+		if(lc($pdoc{$keyword}) =~ /$lckey/){
+		    push(@tmp, $keyword);
+		}elsif(length($lckey) < 1){
+		    push(@tmp, $keyword);
 		}
 	    }
-	}
-
-	msg_send($ans);
+	    
+	    if(scalar(@tmp)){
+		$ans = sprintf("     Found keyword \"%s\" in the following manual pages \(%s hits\).\n\n", $key, scalar(@tmp));
+		
+		foreach my $entry (@tmp){
+		    my $tmp = $pdoc{$entry};
+		    
+		    my $abstract;
+		    if($tmp =~ /Name:\s*(.*)(   -   .*?)\_\_\%\%\%\%\%\_\_/){
+			$abstract = $2;
+		    }
+		    
+		    if($entry =~ /Bio::/){
+			$ans .= sprintf("              %s\n",$entry);
+		    }elsif($entry){
+			$ans .= sprintf("       %-30s%s\n",$entry, $abstract);
+		    }
+		}
+	    }
+	}    
+        msg_send($ans);
 
 	return $ans;
     }else{
@@ -238,7 +294,7 @@ sub process_g{
 
     my $class = 'G';
 
-    if ($File::Find::name =~ /\/([G|SubOpt|Rcmd].*)\.pm$/){
+    if ($File::Find::name =~ /\/((?:G|SubOpt|Rcmd).*)\.pm$/){
 	$class = $1;
 	$class =~ s/\//::/g;
     }else{
@@ -249,8 +305,8 @@ sub process_g{
     while(<FILE>){
 	chomp;
 	if(/^\s*\=head2\s+(.*)\s*$/){
-	    $gclass{$class . '::' . $1} = $1;
 	    my $subname = $1;
+	    $gclass{$subname} = $class;
 
 	    while(<FILE>){
 		chomp;
