@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Alignment.pm,v 1.1.1.1 2002/04/02 20:25:44 gaou Exp $
@@ -32,15 +30,11 @@ use SubOpt;
 use G::Messenger;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
-	     _clustalw
+our @EXPORT = qw(
+		 _clustalw
 );
 
 __DATA__
@@ -127,37 +121,5 @@ sub _clustalw{
     return $file.' '.join(' ',@param);
 }
 
-sub DESTROY {
-    my $self = shift;
-}
 
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Tools::Alignment - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Tools::Alignment;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Tools::Alignment was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
