@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Cap3.pm,v 1.4 2002/08/19 17:22:45 tero Exp $
@@ -32,15 +30,16 @@ use SubOpt;
 use G::Messenger;
 
 use strict;
+use base qw(Exporter);
+use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
-	     _cap3
-	     _makegaplist
+		 _cap3
+		 _makegaplist
 	     );
 
+__DATA__
+
 #::::::::::::::::::::::::::::::
 #        Methods Start
 #::::::::::::::::::::::::::::::
@@ -766,44 +765,9 @@ sub save_allid2{
 }
 
 
-
-
 1;
 
 
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-    
-=head1 NAME
-
-G::Tools::Cap3 - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Tools::Cap3;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Tools::Cap3 was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
-
 
 
 
