@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Rcmd.pm,v 1.3 2002/07/30 17:40:56 gaou Exp $
@@ -32,13 +30,9 @@
 package Rcmd;
 
 use strict;
-use Carp qw(croak);
-use File::Copy;
-
-require Rcmd::Clustering;
-require Rcmd::Normality;
-
-our @ISA = qw(Rcmd::Clustering Rcmd::Normality);
+use base qw(Rcmd::Clustering Rcmd::Normality);
+use autouse 'Carp'=>qw(croak);
+use autouse 'File::Copy'=>qw(copy);
 
 our $VERSION = '1.21';
 
