@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -30,7 +28,7 @@
 package Rcmd::Normality;
 
 use strict;
-use Carp qw(croak carp);
+use autouse 'Carp'=>qw(croak carp);
 
 use SubOpt;
 use G::Messenger;
