@@ -40,20 +40,27 @@ our @EXPORT = qw(
 		 opt_val
 		 opt_get
 		 opt_as_gb
+		 set_opt_list
 );
 
-our $VERSION = '0.30';
+our $VERSION = '0.40';
 
 #::::::::::::::::::::::::::::::
 #          Variables
 #::::::::::::::::::::::::::::::
 
 my %data;
+my $opt_list = 0;
 
 #::::::::::::::::::::::::::::::
 #           Methods
 #::::::::::::::::::::::::::::::
 
+
+sub set_opt_list{
+    $opt_list = shift;
+}
+
 sub opt_as_gb {
 
     if ($#_ >= 1){
@@ -95,6 +102,8 @@ sub opt_as_gb {
 
 sub opt_default{
     %data = (@_);
+
+    die if ($opt_list);
 }
 
 sub opt_val{
